salt.netapi.rest_tornado.saltnado_websockets module
===================================================

.. automodule:: salt.netapi.rest_tornado.saltnado_websockets
    :members:
    :undoc-members:
